Credential class
Constructors
-
Credential(String accessToken, String refreshToken, String idToken, String tokenEndpoint, List<
String> scopes, int expiration) - Credential.fromAccessCredentials(AccessCredentials accessCredentials, String? tokenEndpoint)
- Convenient constructor.
-
Credential.fromMap(Map<
String, dynamic> map)
Properties
- accessToken ↔ String
-
getter/setter pair
- expiration ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- idToken ↔ String
-
getter/setter pair
- refreshToken ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
↔ List<
String> -
getter/setter pair
- tokenEndpoint ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override